==> pmml-model-1.5.15-sources.jar: org/dmg/pmml/time_series/OutlierEffect.java <==

package org.dmg.pmml.time_series;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.dmg.pmml.adapters.RealNumberAdapter;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "OutlierEffect", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions"
})
@Added((org.dmg.pmml.Version.PMML_4_4))
@JsonRootName("OutlierEffect")
@JsonPropertyOrder({
    "type",
    "startTime",
    "magnitude",
    "dampingCoefficient",
    "extensions"
})
public class OutlierEffect
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<OutlierEffect>
{

    @XmlAttribute(name = "type", required = true)
    @JsonProperty("type")
    private String type;
    @XmlAttribute(name = "startTime", required = true)
    @XmlJavaTypeAdapter(RealNumberAdapter.class)
    @JsonProperty("startTime")
    private Number startTime;
    @XmlAttribute(name = "magnitude", required = true)
    @XmlJavaTypeAdapter(RealNumberAdapter.class)
    @JsonProperty("magnitude")
    private Number magnitude;
    @XmlAttribute(name = "dampingCoefficient")
    @XmlJavaTypeAdapter(RealNumberAdapter.class)
    @JsonProperty("dampingCoefficient")
    private Number dampingCoefficient;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67371268L;

    public OutlierEffect() {
    }

    @ValueConstructor
    public OutlierEffect(
        @org.jpmml.model.annotations.Property("type")
        String type,
        @org.jpmml.model.annotations.Property("startTime")
        Number startTime,
        @org.jpmml.model.annotations.Property("magnitude")
        Number magnitude) {
        this.type = type;
        this.startTime = startTime;
        this.magnitude = magnitude;
    }

    public String getType() {
        return type;
    }

    public OutlierEffect setType(
        @org.jpmml.model.annotations.Property("type")
        String type) {
        this.type = type;
        return this;
    }

    public Number getStartTime() {
        return startTime;
    }

    public OutlierEffect setStartTime(
        @org.jpmml.model.annotations.Property("startTime")
        Number startTime) {
        this.startTime = startTime;
        return this;
    }

    public Number getMagnitude() {
        return magnitude;
    }

    public OutlierEffect setMagnitude(
        @org.jpmml.model.annotations.Property("magnitude")
        Number magnitude) {
        this.magnitude = magnitude;
        return this;
    }

    public Number getDampingCoefficient() {
        return dampingCoefficient;
    }

    public OutlierEffect setDampingCoefficient(
        @org.jpmml.model.annotations.Property("dampingCoefficient")
        Number dampingCoefficient) {
        this.dampingCoefficient = dampingCoefficient;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public OutlierEffect addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-1.6.10-sources.jar: org/dmg/pmml/time_series/OutlierEffect.java <==

package org.dmg.pmml.time_series;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.StringValue;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.dmg.pmml.adapters.RealNumberAdapter;
import org.jpmml.model.MissingAttributeException;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "OutlierEffect", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions"
})
@JsonRootName("OutlierEffect")
@JsonPropertyOrder({
    "type",
    "startTime",
    "magnitude",
    "dampingCoefficient",
    "extensions"
})
@Added((org.dmg.pmml.Version.PMML_4_4))
public class OutlierEffect
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<OutlierEffect>
{

    @XmlAttribute(name = "type", required = true)
    @JsonProperty("type")
    private OutlierEffect.Type type;
    @XmlAttribute(name = "startTime", required = true)
    @XmlJavaTypeAdapter(RealNumberAdapter.class)
    @JsonProperty("startTime")
    private Number startTime;
    @XmlAttribute(name = "magnitude", required = true)
    @XmlJavaTypeAdapter(RealNumberAdapter.class)
    @JsonProperty("magnitude")
    private Number magnitude;
    @XmlAttribute(name = "dampingCoefficient")
    @XmlJavaTypeAdapter(RealNumberAdapter.class)
    @JsonProperty("dampingCoefficient")
    private Number dampingCoefficient;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67371271L;

    public OutlierEffect() {
    }

    @ValueConstructor
    public OutlierEffect(
        @org.jpmml.model.annotations.Property("type")
        OutlierEffect.Type type,
        @org.jpmml.model.annotations.Property("startTime")
        Number startTime,
        @org.jpmml.model.annotations.Property("magnitude")
        Number magnitude) {
        this.type = type;
        this.startTime = startTime;
        this.magnitude = magnitude;
    }

    public OutlierEffect.Type requireType() {
        if (this.type == null) {
            throw new MissingAttributeException(this, PMMLAttributes.OUTLIEREFFECT_TYPE);
        }
        return this.type;
    }

    public OutlierEffect.Type getType() {
        return type;
    }

    public OutlierEffect setType(
        @org.jpmml.model.annotations.Property("type")
        OutlierEffect.Type type) {
        this.type = type;
        return this;
    }

    public Number requireStartTime() {
        if (this.startTime == null) {
            throw new MissingAttributeException(this, PMMLAttributes.OUTLIEREFFECT_STARTTIME);
        }
        return this.startTime;
    }

    public Number getStartTime() {
        return startTime;
    }

    public OutlierEffect setStartTime(
        @org.jpmml.model.annotations.Property("startTime")
        Number startTime) {
        this.startTime = startTime;
        return this;
    }

    public Number requireMagnitude() {
        if (this.magnitude == null) {
            throw new MissingAttributeException(this, PMMLAttributes.OUTLIEREFFECT_MAGNITUDE);
        }
        return this.magnitude;
    }

    public Number getMagnitude() {
        return magnitude;
    }

    public OutlierEffect setMagnitude(
        @org.jpmml.model.annotations.Property("magnitude")
        Number magnitude) {
        this.magnitude = magnitude;
        return this;
    }

    public Number getDampingCoefficient() {
        return dampingCoefficient;
    }

    public OutlierEffect setDampingCoefficient(
        @org.jpmml.model.annotations.Property("dampingCoefficient")
        Number dampingCoefficient) {
        this.dampingCoefficient = dampingCoefficient;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(!this.extensions.isEmpty()));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public OutlierEffect addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

    @XmlType(name = "")
    @XmlEnum
    public enum Type
        implements StringValue<OutlierEffect.Type>
    {

        @XmlEnumValue("additive")
        @JsonProperty("additive")
        ADDITIVE("additive"),
        @XmlEnumValue("level")
        @JsonProperty("level")
        LEVEL("level"),
        @XmlEnumValue("transient")
        @JsonProperty("transient")
        TRANSIENT("transient"),
        @XmlEnumValue("seasonalAdditive")
        @JsonProperty("seasonalAdditive")
        SEASONAL_ADDITIVE("seasonalAdditive"),
        @XmlEnumValue("trend")
        @JsonProperty("trend")
        TREND("trend"),
        @XmlEnumValue("innovational")
        @JsonProperty("innovational")
        INNOVATIONAL("innovational");
        private final String value;

        Type(String v) {
            value = v;
        }

        @Override
        public String value() {
            return value;
        }

        public static OutlierEffect.Type fromValue(String v) {
            for (OutlierEffect.Type c: OutlierEffect.Type.values()) {
                if (c.value.equals(v)) {
                    return c;
                }
            }
            throw new IllegalArgumentException(v);
        }

        @Override
        public String toString() {
            return value();
        }

    }

}
